@@ -59,7 +59,7 @@ class SClient(Wss):
             if req.status != 200:return CheckExceptions(await req.json())
             else:return info
 
-    async def login(self, email: str, password: str):
+    async def login(self, email: str, password: str, socket: bool = False):
         data = json.dumps({
             "email": email,
             "secret": f"0 {password}",
@@ -78,7 +78,8 @@ class SClient(Wss):
                 self.headers["NDCAUTH"] = self.sid
                 headers.sid = self.sid
                 headers.uid = self.uid
-                await self.Start()
+                if socket:await self.Start()
+                else: pass
                 return Login(await req.json())
 
     async def logout(self):
@@ -96,7 +97,8 @@ class SClient(Wss):
                 self.uid = None
                 headers.sid = None
                 headers.uid = None
-                await self.close()
+                if self.Ran:await self.close()
+                else:pass
                 return Json((await req.json()))
 
     async def check_device(self, deviceId: str):
@@ -282,7 +284,7 @@ class SClient(Wss):
         data = {"timestamp": int(timestamp() * 1000)}
         if InviteId: data["invitationId"] = InviteId
         data = json.dumps(data)
-        async with self.session.post(api(f"/x{comId}/s/community/join?{self.sid}"), headers=headers.Headers(data=data).headers, data=data) as req:
+        async with self.session.post(api(f"/x{comId}/s/community/join"), headers=headers.Headers(data=data).headers, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json((await req.json()))
 
