@@ -239,9 +239,10 @@ class SLocal:
         if isinstance(userId, str): url = api(f"/x{self.comId}/s/user-profile/{userId}/member")
         elif isinstance(userId, list):
             url = api(f"/x{self.comId}/s/user-profile/{self.uid}/joined")
-            data = json.dumps({"targetUidList": userId, "timestamp": int(timestamp() * 1000)})
+            data["targetUidList"] = userId
         else: raise TypeError("Please put str or list of userId")
 
+        data = json.dumps(data)
         async with self.session.post(url, headers=headers.Headers(data=data).headers, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             return Json(await req.json())
@@ -757,13 +758,14 @@ class SLocal:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return Json(await req.json())
 
-    async def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, backgroundColor: str = None):
+    async def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, backgroundColor: str = None,media: list = None):
         data = {
             "title": title,
             "content": content,
             "timestamp": int(timestamp() * 1000)
         }
-
+        
+        if media: data["mediaList"] = [[100, media, None,"XYZ",None,{"fileName": "Amino"}]]
         if fansOnly: data["extensions"]["fansOnly"] = True
         if backgroundColor: data["extensions"] = {"backgroundColor": backgroundColor}
         if blogId: url = api(f"/x{self.comId}/s/blog/{blogId}")
@@ -827,17 +829,17 @@ class SLocal:
             if "OK" not in (await req.json())["api:message"]: return CheckExceptions(await req.json())
             return Json(await req.json())
 
-    async def send_active_time(self, startTime: int = int(timestamp()), endTime: int = int(timestamp() + 300), optInAdsFlags: int = 2147483647, tz: int = -timezone // 1000, timers: list = None, timestamp: int = int(timestamp() * 1000)):
+    async def send_active_time(self,tz: int = int(-timezone // 1000), timers: list = None):
         data = {
-            "userActiveTimeChunkList": [{"start": startTime, "end": endTime}],
-            "timestamp": timestamp,
-            "optInAdsFlags": optInAdsFlags,
+            "userActiveTimeChunkList": [{"start": int(timestamp()), "end": int(timestamp() + 300)}],
+            "timestamp": int(timestamp() * 1000),
+            "optInAdsFlags": 2147483647,
             "timezone": tz
         }
         if timers: data["userActiveTimeChunkList"] = timers
 
         data = json_minify(json.dumps(data))
-        async with self.session.post(api(f"/x{self.comId}/s/community/stats/user-active-time"), headers=headers.Headers(data=data).headers, data=data) as req:
+        async with self.session.post(api(f"/x{self.comId}/s/community/stats/user-active-time"), headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data) as req:
             if req.status != 200: return CheckExceptions(await req.json())
             else: return Json(await req.json())
 
