@@ -44,7 +44,7 @@ class Client(Wss):
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return info
 
-    def login(self, email: str, password: str):
+    def login(self, email: str, password: str, socket: bool = False):
         data = json.dumps({
             "email": email,
             "secret": f"0 {password}",
@@ -66,7 +66,8 @@ class Client(Wss):
             headers.uid = self.uid
             self.headers = headers.Headers().headers
             self.web_headers = headers.Headers().web_headers
-            self.launch()
+            if socket:self.launch()
+            else: pass
             return Login(req.json())
 
     def logout(self):
@@ -84,7 +85,8 @@ class Client(Wss):
             self.uid = None
             headers.sid = None
             headers.uid = None
-            self.close()
+            if self.isOpened:self.close()
+            else:pass
             return Json(req.json())
 
     def check_device(self, deviceId: str):
