@@ -17,6 +17,7 @@ class Local:
         self.proxies = proxies
         self.comId = comId
         self.uid = headers.uid
+        self.sid = headers.sid
         self.headers = headers.Headers().headers
         self.web_headers = headers.Headers().web_headers
         self.session = requests.Session()
@@ -218,9 +219,10 @@ class Local:
         if isinstance(userId, str): url = api(f"/x{self.comId}/s/user-profile/{userId}/member")
         elif isinstance(userId, list):
             url = api(f"/x{self.comId}/s/user-profile/{self.uid}/joined")
-            data = json.dumps({"targetUidList": userId, "timestamp": int(timestamp() * 1000)})
+            data["targetUidList"] = userId
         else: raise TypeError("Please put str or list of userId")
 
+        data = json.dumps(data)
         req = self.session.post(url, headers=headers.Headers(data=data).headers, proxies=self.proxies, data=data)
         if req.status_code != 200: return CheckExceptions(req.json())
         return Json(req.json())
@@ -730,13 +732,14 @@ class Local:
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
-    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, backgroundColor: str = None):
+    def edit_blog(self, title: str, content: str, blogId: str = None, wikiId: str = None, fansOnly: bool = False, backgroundColor: str = None, media: list = None):
         data = {
             "title": title,
             "content": content,
             "timestamp": int(timestamp() * 1000)
         }
-
+        
+        if media: data["mediaList"] = [[100, media, None,"XYZ",None,{"fileName": "Amino"}]]
         if fansOnly: data["extensions"]["fansOnly"] = True
         if backgroundColor: data["extensions"] = {"backgroundColor": backgroundColor}
         if blogId: url = api(f"/x{self.comId}/s/blog/{blogId}")
@@ -789,11 +792,11 @@ class Local:
         if "OK" not in req.json()["api:message"]: return CheckExceptions(req.json())
         return Json(req.json())
 
-    def send_active_time(self, startTime: int = int(timestamp()), endTime: int = int(timestamp() + 300), optInAdsFlags: int = 2147483647, tz: int = -timezone // 1000, timers: list = None, timestamp: int = int(timestamp() * 1000)):
+    def send_active_time(self,tz: int = int(-timezone // 1000), timers: list = None):
         data = {
-            "userActiveTimeChunkList": [{"start": startTime, "end": endTime}],
-            "timestamp": timestamp,
-            "optInAdsFlags": optInAdsFlags,
+            "userActiveTimeChunkList": [{"start": int(timestamp()), "end": int(timestamp() + 300)}],
+            "timestamp": int(timestamp() * 1000),
+            "optInAdsFlags": 2147483647,
             "timezone": tz
         }
         if timers: data["userActiveTimeChunkList"] = timers
