@@ -1,16 +1,18 @@
-### sockets are edited sockets from libs: Amino-sockets // amino.py
-
+# those sockets are based on: Amino-Sockets / Amino.py
+# Modified by SirLez, zett.0
 import requests
 import websocket
 import threading
 import time as timer
 import ujson as json
-from .lib import util
 from typing import BinaryIO
 from sys import _getframe as getframe
+
+from .lib import util, headers
 from .lib.objects import Event, Payload
 from .lib.exception import CheckExceptions as exception
 
+
 class Callbacks:
     def __init__(self):
         self.handlers = {}
@@ -564,10 +566,10 @@ class Wss(Callbacks, WssClient):
         self.lastMessage = {}
         websocket.enableTrace(trace)
 
-    def onOpen(self, ws=None):
+    def onOpen(self, ws):
         self.isOpened = True
 
-    def onClose(self, ws=None):
+    def onClose(self, ws):
         self.isOpened = False
 
     def send(self, data):
@@ -576,7 +578,7 @@ class Wss(Callbacks, WssClient):
     def receive(self):
         return self.lastMessage
 
-    def on_message(self, data):
+    def on_message(self, ws, data):
         self.lastMessage = json.loads(data)
         self.resolve(data)
 
@@ -614,8 +616,7 @@ class Wss(Callbacks, WssClient):
         else:return response.json()["mediaValue"]
 
     def sendWebActive(self, comId: str):
-
         data = {"ndcId": comId}
-        response = requests.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data, headers=self.web_headers)
+        response = requests.post("https://aminoapps.com/api/community/stats/web-user-active-time", json=data, headers=headers.Headers().web_headers)
         if response.json()["code"] != 200:return exception(response.json())
         else:return response
